@@ -38,7 +38,7 @@ class Categorise(CLIBase):
         currentDirectory = pathlib.Path('.')
 
         for currentFile in currentDirectory.iterdir():
-            if self._cat in currentFile:
+            if self._cat in currentFile.stem:
                 print(currentFile)
 
 #if __name__ == '__main__':
